import pytest
import os
import pandas

is_ci = os.environ.get("CI", "").lower() == "true"


@pytest.mark.skipif(is_ci, reason="CI doesn't usually have WiFi")
def test_nm_loc():
    mozloc = pytest.importorskip("mozloc")
    loc = mozloc.parse_signal(mozloc.get_signal())

    assert isinstance(loc, pandas.DataFrame)
    assert -130 < int(loc["signalStrength"][0]) < 0, "impossible RSSI"


@pytest.mark.skipif(is_ci, reason="CI doesn't usually have WiFi")
def test_nm_connection():
    mozloc = pytest.importorskip("mozloc")
    assert mozloc.cli_config_check()



import os
import functools
import shutil
import subprocess


def running_as_root() -> bool:
    return os.getuid() == 0


@functools.cache
def get_exe(name: str, path: str | None = None) -> str:
    if not (exe := shutil.which(name, path=path)):
        raise FileNotFoundError(name)
    return exe


def get_airport() -> str:
    exe = get_exe(
        "airport",
        "/System/Library/PrivateFrameworks/Apple80211.framework/Versions/Current/Resources",
    )

    msg = subprocess.check_output(exe, text=True, timeout=10)
    if "WARNING: The airport command line tool is deprecated" in msg:
        raise EnvironmentError(msg)

    return exe



"""
https://mozilla.github.io/ichnaea/api/geolocate.html
https://ichnaea.readthedocs.io/en/latest/api/geolocate.html

you should get your own Mozilla Location Services API key

Don't abuse the API or you'll get banned (excessive polling rate)
"""

import argparse
from pprint import pprint

from .base import log_wifi_loc, process_file
from .modules import parse_signal, get_signal


p = argparse.ArgumentParser()
p.add_argument("logfile", help="logfile to append location to", nargs="?")
p.add_argument(
    "-T",
    "--cadence",
    help="how often to update [sec]. Some laptops cannot go faster than 30 sec.",
    default=60,
    type=float,
)
p.add_argument(
    "-url",
    help="Mozilla location services URL--don't use this default test key",
    default="https://location.services.mozilla.com/v1/geolocate?key=test",
)
p.add_argument("-d", "--dump", help="print raw data to console without logging", action="store_true")
p.add_argument("-i", "--infile", help="use raw text saved from command line")
args = p.parse_args()

if args.dump:
    pprint(parse_signal(get_signal()))
elif args.infile:
    process_file(args.infile, mozilla_url=args.url)
else:
    log_wifi_loc(cadence_sec=args.cadence, mozilla_url=args.url, logfile=args.logfile)
